A wrapper function to be used in data.table syntax with lappy. `DUL_LL` function will find the maximum and minimum water content (mm) in a given layer of soil and return its volumn metric content.

DUL_LL(x, thickness)

Arguments

x

A numeric vector. Soil water

thickness

Integer. The depth of a given soil layer in mm.

Value

Max and Min VWC