Edit a base `.apsimx` file with a _kl_ value to update a specific layer in the soil model

EditLayerKL(layer, value, path, apsimx, saveTo)

Arguments

layer

an integer for which layer needs to be modified

value

a floating point number. must be less than 1. this value should be sesenable biologically

path

the path to apsimx `Models.exe`

apsimx

the path to the base `.apsimx` file

saveTo

a path to show where to save modified file. This is for preventing the **Edit** flag overwriten the base `.apsimx` file.

Value