plot_params(
  DT = top5,
  title,
  format = "pdf",
  col_pred = "PSWC",
  col_obs = "SWC",
  group_params = "KLR_RFV_SKL",
  stats = TRUE,
  point_size = 2,
  Depth = NULL,
  width = 10,
  height = 10
)

Arguments

DT

data.table that has predictio and observation data with stats resutls

title

Charater string - Path with file name to save the figure

format

Charater string to indicate output figure format.

col_pred

Charater string - column name for prediction results

col_obs

Charater string - column name for observation results

group_params

Charater strings. The strings are column names which will be used as facet factor

stats

TRUE or FALSE. Default is TRUE where NSE r.square and RMSE must be in the data.table

point_size

Integer - the size of the point

Depth

NULL or charater string to control the facet

  • Default is Null - water profile.

  • "Depth" to check each layer.

  • "Layerkl_distribution" to check the overall distribution of best fit kls in each layer

  • "Layerkl" to check the best fit for each layer with Statistics results

width

Integer. The width of the figure in inches.

height

Integer. The height of the figure in inches.

Value

No values return to the console. Figures will be output directly into the designated folder

Examples

plot_params(DT = top5, title, format = "pdf", col_pred = "PSWC", col_obs = "SWC",point_size = 2,Depth = NULL,width = 10, height = 10)
#> Error in plot_params(DT = top5, title, format = "pdf", col_pred = "PSWC", col_obs = "SWC", point_size = 2, Depth = NULL, width = 10, height = 10): object 'top5' not found