Unlist the stats result to obtain best fit for each layer and join back to the data for further visulisation

subset_stats(DT = DT_stats_layerKL)

Arguments

DT

A data.table with two nested list columns: `data` and `stats`. Column names `Source, Experiment, SowingDate, Depth` must be in the DT as group variables

Value

a data.table has the best fit parameter for each layer in each treatment.

Examples

subset_stats(DT = DT_stats_layerKL)
#> Error in subset_stats(DT = DT_stats_layerKL): object 'DT_stats_layerKL' not found