A wrapper function of `paste` to construct configuration values for `ApsimX` Edit feature.
cat_ParaValue(parameter, values)
| parameter | the address to the parameter that needs to be modified |
|---|---|
| values | a string of values that are separated by comma |
Character string. The string is the path of apsimx submodule and value pair
when replace the number of values must match the number of layers soil parameters.