Take a subset data.table subsetted by the treament and join it with the corresponding simulation results
manipulate(DT_obs = obs, redundant_cols = NULL, DT_pred = dt)
| DT_obs | a data table that subsetted from the aggregated raw data |
|---|---|
| redundant_cols | a string vector. The column names that unwanted in the prediction table. The default mode will remove "CheckpointID", "Experiment", "FolderName" |
| DT_pred | a data table that has the simulation results |
a data table has the same number of rows as the observation data.table