read_met
read_met(path = path_met, skip_unit = 9, skip_meta = 7)
| path | A character string. The path to access the met files. |
|---|---|
| skip_unit | An integer. The number of rows for skipping the unit line in met files. |
| skip_meta | An integer. The number of rows for skipping the meta data before the column names start. |
A data .table and .frame is returned.
if (FALSE) { read_met("path", skip_unit = 9, skip_meta = 7) }